@@ -1,3 +1,5 @@
+#![cfg_attr(not(debug_assertions), windows_subsystem = "windows")] // hide console window on Windows in release
+
 use eframe::{egui, epi};
 
 #[derive(Default)]
@@ -11,7 +13,7 @@ impl epi::App for MyApp {
         "Native file dialogs and drag-and-drop files"
     }
 
-    fn update(&mut self, ctx: &egui::CtxRef, _frame: &epi::Frame) {
+    fn update(&mut self, ctx: &egui::Context, _frame: &epi::Frame) {
         egui::CentralPanel::default().show(ctx, |ui| {
             ui.label("Drag-and-drop files onto the window!");
 
@@ -55,7 +57,7 @@ impl epi::App for MyApp {
 }
 
 impl MyApp {
-    fn detect_files_being_dropped(&mut self, ctx: &egui::CtxRef) {
+    fn detect_files_being_dropped(&mut self, ctx: &egui::Context) {
         use egui::*;
 
         // Preview hovering files:
@@ -80,7 +82,7 @@ impl MyApp {
                 screen_rect.center(),
                 Align2::CENTER_CENTER,
                 text,
-                TextStyle::Heading,
+                TextStyle::Heading.resolve(&ctx.style()),
                 Color32::WHITE,
             );
         }
