@@ -1,3 +1,5 @@
+#![cfg_attr(not(debug_assertions), windows_subsystem = "windows")] // hide console window on Windows in release
+
 use eframe::{egui, epi};
 
 struct MyApp {
@@ -19,20 +21,18 @@ impl epi::App for MyApp {
         "My egui App"
     }
 
-    fn update(&mut self, ctx: &egui::CtxRef, frame: &epi::Frame) {
-        let Self { name, age } = self;
-
+    fn update(&mut self, ctx: &egui::Context, frame: &epi::Frame) {
         egui::CentralPanel::default().show(ctx, |ui| {
             ui.heading("My egui Application");
             ui.horizontal(|ui| {
                 ui.label("Your name: ");
-                ui.text_edit_singleline(name);
+                ui.text_edit_singleline(&mut self.name);
             });
-            ui.add(egui::Slider::new(age, 0..=120).text("age"));
+            ui.add(egui::Slider::new(&mut self.age, 0..=120).text("age"));
             if ui.button("Click each year").clicked() {
-                *age += 1;
+                self.age += 1;
             }
-            ui.label(format!("Hello '{}', age {}", name, age));
+            ui.label(format!("Hello '{}', age {}", self.name, self.age));
         });
 
         // Resize the native window to be just the size we need it to be:
